Constance - Dynamic Django settings
===================================

.. image:: https://secure.travis-ci.org/jazzband/django-constance.svg
    :alt: Build Status
    :target: http://travis-ci.org/jazzband/django-constance

.. image:: https://jazzband.co/static/img/badge.svg
   :alt: Jazzband
   :target: https://jazzband.co/

A Django app for storing dynamic settings in pluggable backends (Redis and
Django model backend built in) with an integration with the Django admin app.

For more information see the documentation at:

https://django-constance.readthedocs.io/

If you have questions or have trouble using the app please file a bug report
at:

https://github.com/jazzband/django-constance/issues
